Source code
===========

.. toctree::

pySOT.adaptive_sampling module
------------------------------

.. automodule:: pySOT.adaptive_sampling
    :members:
    :undoc-members:

pySOT.ensemble_surrogate module
-------------------------------

.. automodule:: pySOT.ensemble_surrogate
    :members:
    :undoc-members:

pySOT.experimental_design module
--------------------------------

.. automodule:: pySOT.experimental_design
    :members:
    :undoc-members:

pySOT.heuristic_methods module
------------------------------

.. automodule:: pySOT.heuristic_methods
    :members:
    :undoc-members:

pySOT.mars_interpolant module
-----------------------------

.. automodule:: pySOT.mars_interpolant
    :members:
    :undoc-members:

pySOT.merit_functions module
----------------------------

.. automodule:: pySOT.merit_functions
    :members:
    :undoc-members:

pySOT.poly_regression module
----------------------------

.. automodule:: pySOT.poly_regression
    :members:
    :undoc-members:

pySOT.kernels module
--------------------

.. automodule:: pySOT.kernels
    :members:
    :undoc-members:

pySOT.tails module
------------------

.. automodule:: pySOT.tails
    :members:
    :undoc-members:

pySOT.rbf module
----------------

.. automodule:: pySOT.rbf
    :members:
    :undoc-members:

pySOT.rs_wrappers module
------------------------

.. automodule:: pySOT.rs_wrappers
    :members:
    :undoc-members:

pySOT.sot_sync_strategies module
--------------------------------

.. automodule:: pySOT.sot_sync_strategies
    :members:
    :undoc-members:

pySOT.test_problems module
--------------------------

.. automodule:: pySOT.test_problems
    :members:
    :undoc-members:

pySOT.utils module
------------------

.. automodule:: pySOT.utils
    :members:
    :undoc-members:
